Category Framework
==================

Introduction
------------

.. toctree::
   :maxdepth: 1

   sage/categories/all

The Sage Category Framework
---------------------------

.. toctree::
   :maxdepth: 1

   sage/categories/primer
   sage/categories/category
   sage/categories/category_with_axiom
   sage/categories/functor
   sage/categories/tutorial

Maps and Morphisms
------------------

.. toctree::
   :maxdepth: 1

   sage/categories/map
   sage/categories/homset
   sage/categories/morphism
   sage/categories/pushout

Individual Categories
---------------------

.. toctree::
   :maxdepth: 1

   sage/categories/action
   sage/categories/additive_groups
   sage/categories/additive_magmas
   sage/categories/additive_monoids
   sage/categories/additive_semigroups
   sage/categories/affine_weyl_groups
   sage/categories/algebra_ideals
   sage/categories/algebra_modules
   sage/categories/algebras
   sage/categories/algebras_with_basis
   sage/categories/aperiodic_semigroups
   sage/categories/associative_algebras
   sage/categories/bialgebras
   sage/categories/bialgebras_with_basis
   sage/categories/bimodules
   sage/categories/classical_crystals
   sage/categories/coalgebras
   sage/categories/coalgebras_with_basis
   sage/categories/commutative_additive_groups
   sage/categories/commutative_additive_monoids
   sage/categories/commutative_additive_semigroups
   sage/categories/commutative_algebra_ideals
   sage/categories/commutative_algebras
   sage/categories/commutative_ring_ideals
   sage/categories/commutative_rings
   sage/categories/complete_discrete_valuation
   sage/categories/complex_reflection_groups
   sage/categories/complex_reflection_or_generalized_coxeter_groups
   sage/categories/coxeter_group_algebras
   sage/categories/coxeter_groups
   sage/categories/crystals
   sage/categories/cw_complexes
   sage/categories/discrete_valuation
   sage/categories/distributive_magmas_and_additive_magmas
   sage/categories/division_rings
   sage/categories/domains
   sage/categories/enumerated_sets
   sage/categories/euclidean_domains
   sage/categories/fields
   sage/categories/filtered_algebras
   sage/categories/filtered_algebras_with_basis
   sage/categories/filtered_modules
   sage/categories/filtered_modules_with_basis
   sage/categories/finite_complex_reflection_groups
   sage/categories/finite_coxeter_groups
   sage/categories/finite_crystals
   sage/categories/finite_dimensional_algebras_with_basis
   sage/categories/finite_dimensional_bialgebras_with_basis
   sage/categories/finite_dimensional_coalgebras_with_basis
   sage/categories/finite_dimensional_graded_lie_algebras_with_basis
   sage/categories/finite_dimensional_hopf_algebras_with_basis
   sage/categories/finite_dimensional_lie_algebras_with_basis
   sage/categories/finite_dimensional_modules_with_basis
   sage/categories/finite_dimensional_nilpotent_lie_algebras_with_basis
   sage/categories/finite_dimensional_semisimple_algebras_with_basis
   sage/categories/finite_enumerated_sets
   sage/categories/finite_fields
   sage/categories/finite_groups
   sage/categories/finite_lattice_posets
   sage/categories/finite_monoids
   sage/categories/finite_permutation_groups
   sage/categories/finite_posets
   sage/categories/finite_semigroups
   sage/categories/finite_sets
   sage/categories/finite_weyl_groups
   sage/categories/finitely_generated_lambda_bracket_algebras
   sage/categories/finitely_generated_lie_conformal_algebras
   sage/categories/finitely_generated_magmas
   sage/categories/finitely_generated_semigroups
   sage/categories/function_fields
   sage/categories/g_sets
   sage/categories/gcd_domains
   sage/categories/generalized_coxeter_groups
   sage/categories/graded_algebras
   sage/categories/graded_algebras_with_basis
   sage/categories/graded_bialgebras
   sage/categories/graded_bialgebras_with_basis
   sage/categories/graded_coalgebras
   sage/categories/graded_coalgebras_with_basis
   sage/categories/graded_hopf_algebras
   sage/categories/graded_hopf_algebras_with_basis
   sage/categories/graded_lie_algebras
   sage/categories/graded_lie_algebras_with_basis
   sage/categories/graded_lie_conformal_algebras
   sage/categories/graded_modules
   sage/categories/graded_modules_with_basis
   sage/categories/graphs
   sage/categories/group_algebras
   sage/categories/groupoid
   sage/categories/groups
   sage/categories/hecke_modules
   sage/categories/highest_weight_crystals
   sage/categories/hopf_algebras
   sage/categories/hopf_algebras_with_basis
   sage/categories/h_trivial_semigroups
   sage/categories/infinite_enumerated_sets
   sage/categories/integral_domains
   sage/categories/j_trivial_semigroups
   sage/categories/kac_moody_algebras
   sage/categories/lambda_bracket_algebras
   sage/categories/lambda_bracket_algebras_with_basis
   sage/categories/lattice_posets
   sage/categories/left_modules
   sage/categories/lie_algebras
   sage/categories/lie_algebras_with_basis
   sage/categories/lie_conformal_algebras
   sage/categories/lie_conformal_algebras_with_basis
   sage/categories/lie_groups
   sage/categories/loop_crystals
   sage/categories/l_trivial_semigroups
   sage/categories/magmas
   sage/categories/magmas_and_additive_magmas
   sage/categories/magmatic_algebras
   sage/categories/manifolds
   sage/categories/matrix_algebras
   sage/categories/metric_spaces
   sage/categories/modular_abelian_varieties
   sage/categories/modules
   sage/categories/modules_with_basis
   sage/categories/monoid_algebras
   sage/categories/monoids
   sage/categories/number_fields
   sage/categories/objects
   sage/categories/partially_ordered_monoids
   sage/categories/permutation_groups
   sage/categories/pointed_sets
   sage/categories/polyhedra
   sage/categories/posets
   sage/categories/principal_ideal_domains
   sage/categories/quotient_fields
   sage/categories/quantum_group_representations
   sage/categories/regular_crystals
   sage/categories/regular_supercrystals
   sage/categories/right_modules
   sage/categories/ring_ideals
   sage/categories/rings
   sage/categories/rngs
   sage/categories/r_trivial_semigroups
   sage/categories/schemes
   sage/categories/semigroups
   sage/categories/semirings
   sage/categories/semisimple_algebras
   sage/categories/sets_cat
   sage/categories/sets_with_grading
   sage/categories/sets_with_partial_maps
   sage/categories/shephard_groups
   sage/categories/simplicial_complexes
   sage/categories/simplicial_sets
   sage/categories/super_algebras
   sage/categories/super_algebras_with_basis
   sage/categories/super_hopf_algebras_with_basis
   sage/categories/super_lie_conformal_algebras
   sage/categories/super_modules
   sage/categories/super_modules_with_basis
   sage/categories/supercommutative_algebras
   sage/categories/supercrystals
   sage/categories/topological_spaces
   sage/categories/triangular_kac_moody_algebras
   sage/categories/unique_factorization_domains
   sage/categories/unital_algebras
   sage/categories/vector_bundles
   sage/categories/vector_spaces
   sage/categories/weyl_groups

Technical Categories
~~~~~~~~~~~~~~~~~~~~

.. toctree::
   :maxdepth: 1

   sage/categories/facade_sets

Functorial constructions
------------------------

.. toctree::
   :maxdepth: 1

   sage/categories/covariant_functorial_construction

   sage/categories/cartesian_product
   sage/categories/tensor
   sage/categories/signed_tensor
   sage/categories/dual
   sage/categories/algebra_functor

   sage/categories/subquotients
   sage/categories/quotients
   sage/categories/subobjects
   sage/categories/isomorphic_objects

   sage/categories/homsets

   sage/categories/realizations
   sage/categories/with_realizations


Examples of parents using categories
-------------------------------------

.. toctree::
   :maxdepth: 1

   sage/categories/examples/algebras_with_basis
   sage/categories/examples/commutative_additive_monoids
   sage/categories/examples/commutative_additive_semigroups
   sage/categories/examples/coxeter_groups
   sage/categories/examples/crystals
   sage/categories/examples/cw_complexes
   sage/categories/examples/facade_sets
   sage/categories/examples/finite_coxeter_groups
   sage/categories/examples/finite_dimensional_algebras_with_basis
   sage/categories/examples/finite_dimensional_lie_algebras_with_basis
   sage/categories/examples/finite_enumerated_sets
   sage/categories/examples/finite_monoids
   sage/categories/examples/finite_semigroups
   sage/categories/examples/finite_weyl_groups
   sage/categories/examples/graded_connected_hopf_algebras_with_basis
   sage/categories/examples/graded_modules_with_basis
   sage/categories/examples/graphs
   sage/categories/examples/hopf_algebras_with_basis
   sage/categories/examples/infinite_enumerated_sets
   sage/categories/examples/lie_algebras
   sage/categories/examples/lie_algebras_with_basis
   sage/categories/examples/magmas
   sage/categories/examples/manifolds
   sage/categories/examples/monoids
   sage/categories/examples/posets
   sage/categories/examples/semigroups
   sage/categories/examples/semigroups_cython
   sage/categories/examples/sets_cat
   sage/categories/examples/sets_with_grading
   sage/categories/examples/with_realizations

Internals
---------

.. toctree::
   :maxdepth: 1

   sage/categories/category_types
   sage/categories/category_singleton
   sage/categories/category_cy_helper
   sage/categories/coercion_methods
   sage/categories/poor_man_map

.. include:: ../footer.txt
